@@ -9,6 +9,7 @@ from django.views.decorators.http import require_POST
 
 
 S3DIRECT_DIR = getattr(settings, "S3DIRECT_DIR", 's3direct')
+S3DIRECT_UNIQUE_RENAME = getattr(settings, "S3DIRECT_UNIQUE_RENAME", None)
 
 
 @csrf_exempt
@@ -16,17 +17,24 @@ S3DIRECT_DIR = getattr(settings, "S3DIRECT_DIR", 's3direct')
 @user_passes_test(lambda u: u.is_staff)
 def get_upload_params(request, upload_to=''):
     content_type = request.POST['type']
-    data = create_upload_data(content_type, upload_to)
+    source_filename = request.POST['name']
+    data = create_upload_data(content_type, source_filename, upload_to)
     return HttpResponse(json.dumps(data), content_type="application/json")
 
 
-def create_upload_data(content_type, upload_to):
-    expires = (datetime.now() + timedelta(hours=24)).strftime('%Y-%m-%dT%H:%M:%S.000Z')
+def create_upload_data(content_type, source_filename, upload_to):
+    access_key = settings.AWS_ACCESS_KEY_ID
+    secret_access_key = settings.AWS_SECRET_ACCESS_KEY
+    bucket = settings.AWS_STORAGE_BUCKET_NAME
+    endpoint = settings.S3DIRECT_ENDPOINT
+
+    expires_in = datetime.now() + timedelta(hours=24)
+    expires = expires_in.strftime('%Y-%m-%dT%H:%M:%S.000Z')
 
     policy_object = json.dumps({
         "expiration": expires,
         "conditions": [
-            {"bucket": settings.AWS_STORAGE_BUCKET_NAME},
+            {"bucket": bucket},
             {"acl": "public-read"},
             {"Content-Type": content_type},
             ["starts-with", "$key", ""],
@@ -35,16 +43,25 @@ def create_upload_data(content_type, upload_to):
     })
 
     policy = b64encode(policy_object.replace('\n', '').replace('\r', ''))
-    signature = b64encode(hmac.new(settings.AWS_SECRET_ACCESS_KEY, policy, hashlib.sha1).digest())
-    key = "%s/%s/${filename}" % (upload_to or S3DIRECT_DIR, uuid.uuid4().hex)
+    signature = hmac.new(secret_access_key, policy, hashlib.sha1).digest()
+    signature_b64 = b64encode(signature)
+
+    if S3DIRECT_UNIQUE_RENAME:
+        ext = source_filename.split('.')[-1]
+        filename = '%s.%s' % (uuid.uuid4(), ext)
+    else:
+        filename = '${filename}'
+
+    key = "%s/%s" % (upload_to or S3DIRECT_DIR, filename)
+    bucket_url = "https://%s/%s" % (endpoint, bucket)
 
     return {
         "policy": policy,
-        "signature": signature,
+        "signature": signature_b64,
         "key": key,
-        "AWSAccessKeyId": settings.AWS_ACCESS_KEY_ID,
-        "form_action": "http://%s.s3.amazonaws.com" % settings.AWS_STORAGE_BUCKET_NAME,
+        "AWSAccessKeyId": access_key,
+        "form_action": bucket_url,
         "success_action_status": "201",
         "acl": "public-read",
         "Content-Type": content_type
-    }
+    }
\ No newline at end of file
